<?php
/*
 * @package     FSCF_SMS
 * @author      Mediaburst
 * @copyright   2012 Mediaburst Ltd
 * @license     ISC
 * @since       0.1
 */
class FSCF_SMS {

	var $version=0.1;

	/*
	 * Initialise values for SMS sending
	 *
	 * @return 	void
	 * @since 	0.1
	 */
	function __construct() {
		// Register hooks needed by this plugin
		if ( function_exists( 'add_action' ) ) {
			add_action( 'init', array( &$this, 'init' ) );
			add_action( 'fsctf_mail_sent', array( &$this, 'mail_sent' ) );
        		add_action( 'fsctf_menu_links', array(&$this, 'menu_links'));
			add_action( 'admin_menu', array( &$this, 'admin_menu' ) );
			add_action( 'admin_init', array( &$this, 'admin_init' ) );
		}
	}

	/* 
	 * Hook in to WordPress initialisation phase
	 *
	 * @return 	void
	 * @since 	0.1
	 */
	function init () {
		// Load text domain for i18n
		load_plugin_textdomain( 'fscf_sms', false, FSCF_SMS_PLUGIN_DIR.'/languages' );
	}

	/* 
	 * Action to fire when Fast Secure Contact Form has sent the email
	 *
	 * @param 	$fscf Fast Secure Contact Form object
	 * @return 	void
	 * @since	0.1
	 */
	function mail_sent( $fscf ) {
		/* $fscf->posted_data[''];
		   from_name, from_email, message, subject, full_message
		*/
		$options = get_option('fscf_sms');

		if( $options != null && isset( $options['username'] ) && isset( $options['password'] ) && isset( $options['mobile'] ) 
			&& $options['username'] != '' && $options['password'] != '' && $options['mobile'] != '' ) {

			// Put name in message if it's available
			if( $fscf->posted_data != null && $fscf->posted_data['from_name'] != null && trim( $fscf->posted_data['from_name'] ) != '' ) {
				$name = trim( $fscf->posted_data['from_name'] );
			} else {
				$name = 'Somebody';
			}

			$message = $name.' filled in your contact form. Check your email';
			$mobile = explode( ',', $options['mobile'] );

			try {
				$sms = $this->get_mediaburst_sms();
				$sms_result = $sms->Send( $mobile, $message );
			} catch( mediaburstException $e ) {
				//TODO: handle error
			} catch (Exception $e) {
				//TODO: handle error
			}
		}
	}

	/*
	 * Get a mediaburstSMS object with sensible defaults set
	 * Saves having to set these defaults every time
	 *
	 * @returns 	mediaburstSMS object
	 * @since	0.1
	 */
	function get_mediaburst_sms() {
		$sms_options = array(
			'long'          => true,
			'truncate'      => true,
			'http_class'    => 'WordPressMBHTTP',
	        );
		$options = get_option('fscf_sms');
		return new mediaburstSMS( $options['username'], $options['password'], $sms_options );	
	}


	/*
	 * Add menu links on Fast Secure Contact Form page
	 *
	 * @return	string - menu HTML
	 * @since 	0.1
	 */
	function menu_links() {
		printf( '<p>%s | Version %s | <a href="options-general.php?page=fscf-sms">%s</a></p>', __( 'SMS Addon', 'fscf_sms' ), $this->version, __( 'Settings', 'fscf_sms' ) );
	}

	/*
	 * Add menu item to WordPress settings menu, and regiter the options page
	 *
	 * @return	void
	 * @since	0.1
	 */
	function admin_menu() {
		add_options_page( 'Fast Secure Contact Form - SMS Addon', 'FS Contact Form SMS', 'manage_options', 'fscf-sms', array( &$this, 'options_page' ) );
	}

	/*
	 * Initialise hooks for admin pages
	 *
	 * @return	void
	 * @since	0.1
	 */
	function admin_init() {
		register_setting( 'fscf_sms', 'fscf_sms', array( &$this, 'validate_option' ) );

		add_settings_section( 'fscf_sms_general', 'General Settings', array( &$this, 'opt_section_general' ), 'fscf_sms' );
		add_settings_field( 'fscf_sms_active', 'Send SMS', array(&$this, 'opt_value_active' ), 'fscf_sms', 'fscf_sms_general' );
		add_settings_field( 'fscf_sms_mobile', 'Mobile', array( &$this, 'opt_value_mobile' ), 'fscf_sms', 'fscf_sms_general' );

		add_settings_section( 'fscf_sms_mediaburst', 'Mediaburst Account', array( &$this, 'opt_section_mediaburst' ), 'fscf_sms' );
		add_settings_field( 'fscf_sms_username', 'Username', array( &$this, 'opt_value_username' ), 'fscf_sms', 'fscf_sms_mediaburst' );	
		add_settings_field( 'fscf_sms_password', 'Password', array( &$this, 'opt_value_password' ), 'fscf_sms', 'fscf_sms_mediaburst' );

	}

	/* 
	 * Display the plugins options page
	 *
	 * @return	void
	 * @since	0.1
	 */
	function options_page() {
		include( FSCF_SMS_PLUGIN_DIR.'/includes/form-admin-options.php' );
	}

	/* 
	 * Validate option fields
	 *
	 * @param	$input - Asssociative array of new option values
	 * @return	Associative array of sanitised option values
	 * @since	0.1
	 */
	function validate_option($input) {
		$options = get_option('fscf_sms');
		$options['active'] = $input['active'];
		$options['mobile'] = trim( $input['mobile'] );
		$options['username'] = trim( $input['username'] );
		$options['password'] = trim( $input['password'] );
		/*if(!preg_match('/^[a-z0-9]{32}$/i', $options['text_string'])) {
			$options['text_string'] = '';
		}*/
		return $options;
	}

	/*
	 * The opt_section_* functions Render an introduction to each settings section
	 */
	function opt_section_general() {
		echo "";
	}
	function opt_section_mediaburst() {
		echo '<p>To use the SMS notifications you need a <a href="http://www.mediaburst.co.uk/api/?utm_source=wordpress&utm_medium=plugin&utm_campaign=fscf-sms">mediaburst SMS API</a> account.</p>';
	}

	/*
	 * The opt_value_* functions Render input fields for options
	 */
	function opt_value_username() {
		$options = get_option('fscf_sms');
		echo "<input id='fscf_sms_username' name='fscf_sms[username]' size='40' type='text' value='{$options['username']}' />";
	}
	function opt_value_password() {
		$options = get_option('fscf_sms');
		echo "<input id='fscf_sms_password' name='fscf_sms[password]' size='40' type='password' value='{$options['password']}' />";
	}
	function opt_value_active() {
		$options = get_option('fscf_sms');
		$checked = ($options["active"]) ? 'checked="checked"' : '';
		echo "<input id='fscf_sms_active' name='fscf_sms[active]' type='checkbox' value='1' {$checked} />";
	}
	function opt_value_mobile() {
		$options = get_option('fscf_sms');
		echo "<input id='fscf_sms_mobile' name='fscf_sms[mobile]' size='40' type='tel' value='{$options['mobile']}' />";
		echo ' <span class="description">'.__('International format, starting with a country code e.g. 447123456789', 'fscf_sms').'</span>';
	}
}
